@@ -6,7 +6,7 @@ set -e
 #------------------------------------------------------------------------------
 # parse parameters
 #------------------------------------------------------------------------------
-Usage="Usage: $0 <LazarusSrcDir>"
+Usage="Usage: $0 <LazarusSrcDir> <FPCFullVersion>  [append-revision]"
 
 LazSrcDir=$1
 shift
@@ -25,19 +25,35 @@ if [ ! -d $LazSrcDir/.svn ]; then
   exit -1
 fi
 
+FpcFullVersion=$1
+shift
+if [ "x$FpcFullVersion" = "x" ]; then
+  echo $Usage
+  exit -1
+fi
+
+cd $(dirname $0)
+if [ "$1" = "append-revision" ]; then
+  LazVersionPostfix=$(./get_svn_revision_number.sh $LazSrcDir)
+  if [ -n "$LazVersionPostfix" ]; then
+    LazVersionPostfix=.$LazVersionPostfix
+  fi
+  shift
+fi
+
 Date=`date +%Y%m%d`
 # get fpc snapshot rpm
 RPMDIR=$(rpm/get_rpm_source_dir.sh)
 ARCH=`rpm --eval "%{_arch}"`
 LIB=`rpm --eval "%{_lib}"`
-FPCRPM=$RPMDIR/RPMS/$ARCH/fpc-2.2.0-$Date.$ARCH.rpm
+FPCRPM=$RPMDIR/RPMS/$ARCH/fpc-$FpcFullVersion-$Date.$ARCH.rpm
 if [ ! -f $FPCRPM ]; then
   echo ERROR: fpc rpm $FPCRPM not available
   exit
 fi
 
-User=`whoami`
-TmpFPCDir=/tmp/$User/fpc
+# extract the fpc snapshot, so we don't need to install it
+TmpFPCDir=~/tmp/fpc
 if [ -e $TmpFPCDir ]; then
   rm -rf $TmpFPCDir
 fi 
@@ -45,6 +61,7 @@ mkdir -p $TmpFPCDir
 cd $TmpFPCDir
 rpm2cpio $FPCRPM | cpio -id 
 FPCVersion=`usr/bin/fpc -iV`
+FPCFullVersion=`usr/bin/fpc -iW`
 usr/$LIB/fpc/$FPCVersion/samplecfg $TmpFPCDir/usr/$LIB/fpc/$FPCVersion .
 FPCCfg=$TmpFPCDir/fpc.cfg
 export FPCCfg
@@ -55,39 +72,41 @@ export FPCDIR
 cd -
 
 # create a temporary copy of the lazarus sources for packaging
-LazVersion=$(./get_lazarus_version.sh)
+LazVersion=$(./get_lazarus_version.sh)$LazVersionPostfix
 LazRelease=`echo $FPCRPM | sed -e 's/-/_/g'`
-TmpDir=/tmp/`whoami`/lazarus
+TmpLazDir=~/tmp/lazarus
 
-rm -rf $TmpDir
+rm -rf $TmpLazDir
 echo "extracting Lazarus source from local svn ..."
-svn export $LazSrcDir $TmpDir
+svn export $LazSrcDir $TmpLazDir
 if [ ! -e ../svn2revisioninc ]; then
   make -C ../.. tools OPT="-n @$FPCCfg"
 fi
-../svn2revisioninc $LazSrcDir $TmpDir/ide/revision.inc
+../svn2revisioninc $LazSrcDir $TmpLazDir/ide/revision.inc
 
 # create a source tar.gz
-cd $TmpDir/..
+cd $TmpLazDir/..
 tar -czf $RPMDIR/SOURCES/lazarus-$LazVersion-$Date.tar.gz lazarus
 
 # remove the tempdir
 cd -
-rm -rf $TmpDir
+rm -rf $TmpLazDir
 
 # create spec file
 SpecFile=$RPMDIR/SPECS/lazarus-$LazVersion-$Date.spec
 cat rpm/lazarus.spec.template | \
   sed -e "s/LAZVERSION/$LazVersion/g" \
       -e "s/LAZRELEASE/$Date/g" \
-      -e "s/FPCVERSION/$FPCVersion/g" \
-      -e "s/FPCSRCVERSION/$FPCVersion/g" \
+      -e "s/FPCVERSION/$FPCFullVersion/g" \
+      -e "s/FPCSRCVERSION/$FPCFullVersion/g" \
   > $SpecFile
 
 # build rpm
 rpmbuild --target $ARCH -ba $SpecFile --nodeps
 
-rm -rf $TmpFpcDir
+# remove the temp fpc dir
+rm -rf $TmpFPCDir
+
 
 # end.
 
